@@ -20,8 +20,17 @@ module Control.Concurrent.STM.SSemInternals(SSem(SSem)) where
 import Control.Concurrent.STM.TVar(TVar)
 import Data.Typeable(Typeable) -- Typeable(typeOf),TyCon,mkTyCon,mkTyConApp)
 
+#if __GLASGOW_HASKELL__ < 707
 #include "Typeable.h"
+#endif
 
-newtype SSem = SSem (TVar Int)  deriving (Eq)
+newtype SSem = SSem (TVar Int)
+             deriving ( Eq
+#if __GLASGOW_HASKELL__ >= 707
+                      , Typeable
+#endif
+                      )
 
+#if __GLASGOW_HASKELL__ < 707
 INSTANCE_TYPEABLE0(SSem,semTc,"SSem")
+#endif
